from setuptools import setup

setup(name='fzysearch',
      version='0.2',
      description='fuzzy searches a string input to a list and returns results from the list in order of relevance',
      url='http://github.com/ridwanmsharif/fzysearch',
      author='Ridwan M. Sharif',
      author_email='ridwanmsharif@hotmail.com',
      license='MIT',
      packages=['fzysearch'],
      zip_safe=False)
